@@ -281,12 +281,12 @@
 <context>
     <name>extension_CommandPalette</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="98"/>
+        <location filename="../../translation_tools/translatables.py" line="134"/>
         <source>Trigger menu actions</source>
         <translation>Activer les actions du menu</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="97"/>
+        <location filename="../../translation_tools/translatables.py" line="133"/>
         <source>Command palette</source>
         <translation>Palette de commandes</translation>
     </message>
@@ -294,17 +294,17 @@
 <context>
     <name>extension_DataViewer</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="3"/>
+        <location filename="../../translation_tools/translatables.py" line="96"/>
         <source>Load into workspace (DataMatrix) and view</source>
         <translation>Charger dans l&apos;espace de travail (DataMatrix) et afficher</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="5"/>
+        <location filename="../../translation_tools/translatables.py" line="98"/>
         <source>DataViewer</source>
         <translation>DataViewer</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="4"/>
+        <location filename="../../translation_tools/translatables.py" line="97"/>
         <source>Load into workspace (PIL image) and view</source>
         <translation>Charger dans l&apos;espace de travail (image PIL) et afficher</translation>
     </message>
@@ -312,22 +312,22 @@
 <context>
     <name>extension_FindInFiles</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="11"/>
+        <location filename="../../translation_tools/translatables.py" line="93"/>
         <source>Find in project files</source>
         <translation>Rechercher dans les fichiers des projets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="8"/>
+        <location filename="../../translation_tools/translatables.py" line="90"/>
         <source>Find text in project files</source>
         <translation>Trouver du text dans les fichiers des projets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="9"/>
+        <location filename="../../translation_tools/translatables.py" line="92"/>
         <source>FindInFiles requires the OpenSesameIDE extension</source>
         <translation>FindInFiles à besoin de l&apos;extension OpenSesameIDE</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="10"/>
+        <location filename="../../translation_tools/translatables.py" line="91"/>
         <source>Find in projects</source>
         <translation>Recherchers dans les projets</translation>
     </message>
@@ -335,17 +335,17 @@
 <context>
     <name>extension_GitGUI</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="124"/>
+        <location filename="../../translation_tools/translatables.py" line="3"/>
         <source>Start Git GUI</source>
         <translation>Démarrer Git GUI</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="125"/>
+        <location filename="../../translation_tools/translatables.py" line="5"/>
         <source>Starts Git GUI</source>
         <translation>Démarre Git GUI</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="126"/>
+        <location filename="../../translation_tools/translatables.py" line="4"/>
         <source>Launch Git GUI</source>
         <translation>Lancer Git GUI</translation>
     </message>
@@ -353,27 +353,27 @@
 <context>
     <name>extension_JupyterConsole</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="130"/>
+        <location filename="../../translation_tools/translatables.py" line="140"/>
         <source>Show Jupyter/ IPython console</source>
         <translation>Montrer la console Jupyter/ IPython</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="132"/>
+        <location filename="../../translation_tools/translatables.py" line="138"/>
         <source>Restart kernel</source>
         <translation>Redémarrer le noyau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="129"/>
+        <location filename="../../translation_tools/translatables.py" line="137"/>
         <source>Start new console</source>
         <translation>Lancer une nouvelle console</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="131"/>
+        <location filename="../../translation_tools/translatables.py" line="139"/>
         <source>Show console</source>
         <translation>Montrer la console</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="133"/>
+        <location filename="../../translation_tools/translatables.py" line="141"/>
         <source>The {} (inprocess={}) kernel does not support debugging</source>
         <translation>Le noyau {} (inprocess={}) ne prend pas en charge le débogage</translation>
     </message>
@@ -381,37 +381,37 @@
 <context>
     <name>extension_JupyterNotebook</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="89"/>
+        <location filename="../../translation_tools/translatables.py" line="12"/>
         <source>Open Jupyter/ IPython Notebook</source>
         <translation>Ouvrir Notebook Jupyter/ IPython</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="92"/>
+        <location filename="../../translation_tools/translatables.py" line="8"/>
         <source>Import notebook</source>
         <translation>Importer notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="90"/>
+        <location filename="../../translation_tools/translatables.py" line="9"/>
         <source>Failed to read notebook. See console for details.</source>
         <translation>Le chargement du notebook à échoué. Voir la console pour plus de details.</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="94"/>
+        <location filename="../../translation_tools/translatables.py" line="10"/>
         <source>Launch Jupyter Lab</source>
         <translation>Démarrer Jupyter Lab</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="88"/>
+        <location filename="../../translation_tools/translatables.py" line="11"/>
         <source>Export notebook</source>
         <translation>Exporter notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="91"/>
+        <location filename="../../translation_tools/translatables.py" line="13"/>
         <source>Import and export Jupyter Notebook (.ipynb) files</source>
         <translation>Importer et exporter des fichiers Jupyter Notebook (.ipynb)</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="93"/>
+        <location filename="../../translation_tools/translatables.py" line="14"/>
         <source>Import as Python script</source>
         <translation>Importer en tant que script de Python</translation>
     </message>
@@ -419,242 +419,242 @@
 <context>
     <name>extension_OpenSesameIDE</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="80"/>
+        <location filename="../../translation_tools/translatables.py" line="69"/>
         <source>Open file</source>
         <translation>Ouvrir un fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="82"/>
+        <location filename="../../translation_tools/translatables.py" line="40"/>
         <source>&amp;Save</source>
         <translation>&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="54"/>
+        <location filename="../../translation_tools/translatables.py" line="85"/>
         <source>&amp;Tools</source>
         <translation>&amp;Outils</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="76"/>
+        <location filename="../../translation_tools/translatables.py" line="80"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="41"/>
+        <location filename="../../translation_tools/translatables.py" line="53"/>
         <source>&amp;View</source>
         <translation>&amp;Vue</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="73"/>
+        <location filename="../../translation_tools/translatables.py" line="63"/>
         <source>&amp;Interrupt kernel</source>
         <translation>&amp;Interrompre le noyau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="35"/>
+        <location filename="../../translation_tools/translatables.py" line="87"/>
         <source>Not indexing {} (too many files)</source>
         <translation>Pas d&apos;indexation de {} (trop de fichiers)</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="77"/>
+        <location filename="../../translation_tools/translatables.py" line="30"/>
         <source>Running notebook cell</source>
         <translation>Exécuter cellule de notebook</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="38"/>
+        <location filename="../../translation_tools/translatables.py" line="31"/>
         <source>Split &amp;vertical</source>
         <translation>Division &amp;vertical</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="47"/>
+        <location filename="../../translation_tools/translatables.py" line="70"/>
         <source>Fixed editor width</source>
         <translation>Largeur de l&apos;éditeur fixée</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="45"/>
+        <location filename="../../translation_tools/translatables.py" line="74"/>
         <source>Run &amp;selection, cell, or current line</source>
         <translation>Exécuter la &amp;sélection, la cellule ou la ligne actuelle</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="65"/>
+        <location filename="../../translation_tools/translatables.py" line="54"/>
         <source>Running current line</source>
         <translation>En train d&apos;exécuter la ligne actuelle</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="70"/>
+        <location filename="../../translation_tools/translatables.py" line="67"/>
         <source>How do you want to open this file?</source>
         <translation>Comment voulez-vous ouvrir ce fichier ?</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="69"/>
+        <location filename="../../translation_tools/translatables.py" line="58"/>
         <source>Close &amp;all tabs</source>
         <translation>Fermer &amp;tous les onglets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="72"/>
+        <location filename="../../translation_tools/translatables.py" line="35"/>
         <source>Code completion</source>
         <translation>Complétion de code</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="29"/>
+        <location filename="../../translation_tools/translatables.py" line="32"/>
         <source>&amp;Locate active file</source>
         <translation>&amp;Localiser le fichier actuel</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="81"/>
+        <location filename="../../translation_tools/translatables.py" line="79"/>
         <source>Select indentation mode</source>
         <translation>Sélectionner le mode d&apos;indentation</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="58"/>
+        <location filename="../../translation_tools/translatables.py" line="68"/>
         <source>Wrap lines</source>
         <translation>Retour à ligne</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="36"/>
+        <location filename="../../translation_tools/translatables.py" line="61"/>
         <source>Open as text</source>
         <translation>Ouvrir comme texte</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="24"/>
+        <location filename="../../translation_tools/translatables.py" line="41"/>
         <source>&amp;New</source>
         <translation>&amp;Nouveau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="79"/>
+        <location filename="../../translation_tools/translatables.py" line="76"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="26"/>
+        <location filename="../../translation_tools/translatables.py" line="29"/>
         <source>Switch to previous panel</source>
         <translation>Passer au panneau précedent</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="68"/>
+        <location filename="../../translation_tools/translatables.py" line="73"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Préférences</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="62"/>
+        <location filename="../../translation_tools/translatables.py" line="66"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="27"/>
+        <location filename="../../translation_tools/translatables.py" line="49"/>
         <source>Code folding</source>
         <translation>Pliage de code</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="48"/>
+        <location filename="../../translation_tools/translatables.py" line="37"/>
         <source>Turn OpenSesame into an IDE</source>
         <translation>Changer OpenSesame en IDE</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="57"/>
+        <location filename="../../translation_tools/translatables.py" line="42"/>
         <source>P&amp;lugins</source>
         <translation>P&amp;lugins</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="61"/>
+        <location filename="../../translation_tools/translatables.py" line="48"/>
         <source>Switch to next panel</source>
         <translation>Passer au panneau suivant</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="37"/>
+        <location filename="../../translation_tools/translatables.py" line="36"/>
         <source>Running project</source>
         <translation>En train d&apos;exécuter le projet</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="25"/>
+        <location filename="../../translation_tools/translatables.py" line="64"/>
         <source>Close &amp;other tabs</source>
         <translation>Fermer les &amp;autres onglets</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="31"/>
+        <location filename="../../translation_tools/translatables.py" line="56"/>
         <source>&amp;Run</source>
         <translation>&amp;Exécuter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="67"/>
+        <location filename="../../translation_tools/translatables.py" line="62"/>
         <source>&amp;Close tab</source>
         <translation>&amp;Fermer l&apos;onglet</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="75"/>
+        <location filename="../../translation_tools/translatables.py" line="65"/>
         <source>Restart &amp;kernel</source>
         <translation>Redémarrer le &amp;noyau</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="53"/>
+        <location filename="../../translation_tools/translatables.py" line="50"/>
         <source>Save and run</source>
         <translation>Enregistrer et exécuter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="42"/>
+        <location filename="../../translation_tools/translatables.py" line="83"/>
         <source>Show right margin</source>
         <translation>Montrer la marge droite</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="50"/>
+        <location filename="../../translation_tools/translatables.py" line="43"/>
         <source>Running file</source>
         <translation>En train d&apos;exécuter le fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="63"/>
+        <location filename="../../translation_tools/translatables.py" line="78"/>
         <source>Split &amp;horizontal</source>
         <translation>Division &amp;horizontal</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="56"/>
+        <location filename="../../translation_tools/translatables.py" line="86"/>
         <source>Show editor tabs</source>
         <translation>Montrer les onglets de l&apos;éditeur</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="52"/>
+        <location filename="../../translation_tools/translatables.py" line="81"/>
         <source>Unsaved changes</source>
         <translation>Modifications non enregistrées</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="49"/>
+        <location filename="../../translation_tools/translatables.py" line="55"/>
         <source>Running selection</source>
         <translation>En train d&apos;exécuter la sélection</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="30"/>
+        <location filename="../../translation_tools/translatables.py" line="60"/>
         <source>Show whitespace</source>
         <translation>Montrer les espaces</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="40"/>
+        <location filename="../../translation_tools/translatables.py" line="59"/>
         <source>&amp;Close all folders</source>
         <translation>&amp;Fermer tous les navigateurs de dossiers</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="60"/>
+        <location filename="../../translation_tools/translatables.py" line="39"/>
         <source>Show line numbers</source>
         <translation>Montrer les numéros des lignes</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="39"/>
+        <location filename="../../translation_tools/translatables.py" line="52"/>
         <source>Toggle fullscreen</source>
         <translation>Basculer mode plein écran</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="34"/>
+        <location filename="../../translation_tools/translatables.py" line="51"/>
         <source>&amp;Editor</source>
         <translation>&amp;Éditeur</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="78"/>
+        <location filename="../../translation_tools/translatables.py" line="47"/>
         <source>&amp;Run project or file</source>
         <translation>&amp;Exécuter projet ou fichier</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="59"/>
+        <location filename="../../translation_tools/translatables.py" line="75"/>
         <source>Change &amp;working directory to active file</source>
         <translation>Changer le &amp;répertoire de travail vers le fichier actuel</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="64"/>
+        <location filename="../../translation_tools/translatables.py" line="45"/>
         <source>Toggle &amp;folder browsers</source>
         <translation>Basculer les &amp;navigateurs de dossiers</translation>
     </message>
@@ -689,57 +689,57 @@
         <translation type="obsolete">Enregistrer &amp;sous…</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="33"/>
+        <location filename="../../translation_tools/translatables.py" line="82"/>
         <source>Save, run, and don&apos;t ask again</source>
         <translation>Enregistrer, exécuter, et ne plus demander</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="43"/>
+        <location filename="../../translation_tools/translatables.py" line="72"/>
         <source>Search project files or browse disk …</source>
         <translation>Rechercher dans les fichiers des projets ou parcourir le disque …</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="28"/>
+        <location filename="../../translation_tools/translatables.py" line="38"/>
         <source>Save &amp;as…</source>
         <translation>Enregistrer &amp;sous…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="55"/>
+        <location filename="../../translation_tools/translatables.py" line="71"/>
         <source>Browse disk …</source>
         <translation>Parcourir le disque …</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="74"/>
+        <location filename="../../translation_tools/translatables.py" line="44"/>
         <source>Open &amp;folder…</source>
         <translation>Ouvrir un &amp;dossier…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="51"/>
+        <location filename="../../translation_tools/translatables.py" line="77"/>
         <source>&amp;Open…</source>
         <translation>&amp;Ouvrir…</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="66"/>
+        <location filename="../../translation_tools/translatables.py" line="84"/>
         <source>Search recent folders or browse disk …</source>
         <translation>Parcourir</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="32"/>
+        <location filename="../../translation_tools/translatables.py" line="57"/>
         <source>Cannot save file with this encoding</source>
         <translation>Ne peut pas enregistrer le fichier avec cet encodage</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="44"/>
+        <location filename="../../translation_tools/translatables.py" line="46"/>
         <source>Run file in &amp;debugger</source>
         <translation>Exécuter le fichier dans le &amp;débogueur</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="71"/>
+        <location filename="../../translation_tools/translatables.py" line="34"/>
         <source>Clear &amp;breakpoints</source>
         <translation>Enlever les &amp;points d&apos;arret</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="46"/>
+        <location filename="../../translation_tools/translatables.py" line="33"/>
         <source>&amp;Toggle breakpoint</source>
         <translation>&amp;Basculer un point d&apos;arrêt</translation>
     </message>
@@ -747,12 +747,12 @@
 <context>
     <name>extension_PythonDebugger</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="105"/>
+        <location filename="../../translation_tools/translatables.py" line="130"/>
         <source>Connects to the Rapunzel PDB</source>
         <translation>Se connecte avec le débogueur Rapunzel</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="106"/>
+        <location filename="../../translation_tools/translatables.py" line="129"/>
         <source>Python Debugger</source>
         <translation>Débogueur Python</translation>
     </message>
@@ -760,12 +760,12 @@
 <context>
     <name>extension_QuickSelector</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="14"/>
+        <location filename="../../translation_tools/translatables.py" line="121"/>
         <source>A general-purpose quick-select dialog</source>
         <translation>Une boîte de dialogue de sélection rapide à usage général</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="15"/>
+        <location filename="../../translation_tools/translatables.py" line="122"/>
         <source>Select stuff quickly</source>
         <translation>Sélectionner des choses rapidement</translation>
     </message>
@@ -773,7 +773,7 @@
 <context>
     <name>extension_RapunzelLocale</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="109"/>
+        <location filename="../../translation_tools/translatables.py" line="112"/>
         <source>Installs translation for Rapunzel extensions</source>
         <translation>Installe la traduction des extensions Rapunzel</translation>
     </message>
@@ -781,12 +781,12 @@
 <context>
     <name>extension_RapunzelWelcome</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="102"/>
+        <location filename="../../translation_tools/translatables.py" line="125"/>
         <source>Get started!</source>
         <translation>Lancez-vous !</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="101"/>
+        <location filename="../../translation_tools/translatables.py" line="126"/>
         <source>A welcome tab for Rapunzel</source>
         <translation>Un onglet de bienvenue pour Rapunzel</translation>
     </message>
@@ -794,25 +794,65 @@
 <context>
     <name>extension_SpellCheck</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="85"/>
+        <location filename="../../translation_tools/translatables.py" line="102"/>
         <source>Check spelling</source>
         <translation>Vérifier l&apos;ortographe</translation>
     </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="101"/>
+        <source>French</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="103"/>
+        <source>Spanish</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="104"/>
+        <source>Please install pyspellchecker for spell checking</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="105"/>
+        <source>English</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="106"/>
+        <source>Disable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../../translation_tools/translatables.py" line="107"/>
+        <source>Set language for spell checking …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="108"/>
+        <source>German</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../translation_tools/translatables.py" line="109"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>extension_SymbolSelector</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="121"/>
+        <location filename="../../translation_tools/translatables.py" line="19"/>
         <source>Symbol selector</source>
         <translation>Sélecteur de symboles</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="120"/>
+        <location filename="../../translation_tools/translatables.py" line="18"/>
         <source>Quickly jump to functions, classes, and other symbol definitions</source>
         <translation>Accédez rapidement aux fonctions, classes et autres définitions de symboles</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../../translation_tools/translatables.py" line="119"/>
+        <location filename="../../translation_tools/translatables.py" line="17"/>
         <source>Search symbols in current file …</source>
         <translation>Rechercher des symboles dans le fichier actuel …</translation>
     </message>
@@ -820,22 +860,22 @@
 <context>
     <name>extension_WordCount</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="19"/>
+        <location filename="../../translation_tools/translatables.py" line="117"/>
         <source>Word count</source>
         <translation>Nombre de mot</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="21"/>
+        <location filename="../../translation_tools/translatables.py" line="115"/>
         <source>{} lines, {} words, {} characters</source>
         <translation>{} lignes, {} mots, {} caractères</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="18"/>
+        <location filename="../../translation_tools/translatables.py" line="116"/>
         <source>Nothing to count</source>
         <translation>Rien à compter</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="20"/>
+        <location filename="../../translation_tools/translatables.py" line="118"/>
         <source>Counts the number of lines, words, and characters</source>
         <translation>Compte le nombre de lignes, de mots et de caractères</translation>
     </message>
@@ -843,27 +883,27 @@
 <context>
     <name>extension_WorkspaceExplorer</name>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="112"/>
+        <location filename="../../translation_tools/translatables.py" line="22"/>
         <source>Workspace ({})</source>
         <translation>Espace de travail ({})</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="116"/>
+        <location filename="../../translation_tools/translatables.py" line="23"/>
         <source>Show Python workspace explorer</source>
         <translation>Afficher l&apos;explorateur d&apos;espace de travail Python</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="114"/>
+        <location filename="../../translation_tools/translatables.py" line="24"/>
         <source>Show workspace</source>
         <translation>Afficher l&apos;espace de travail</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="113"/>
+        <location filename="../../translation_tools/translatables.py" line="26"/>
         <source>Workspace</source>
         <translation>Espace de travail</translation>
     </message>
     <message>
-        <location filename="../../translation_tools/translatables.py" line="115"/>
+        <location filename="../../translation_tools/translatables.py" line="25"/>
         <source>Cannot inspect variables in running kernel</source>
         <translation>Ne peut pas visualiser des variables à partir d&apos;un noyau en cours d&apos;exécution</translation>
     </message>
